@@ -91,7 +91,7 @@ class HealthLogUi:
 			if 'EntryBarcode' in useColumns:
 				h=f'{Fore.light_red}HealthLog{Fore.light_yellow}@{Style.bold}{Fore.deep_sky_blue_3b}AHS{Fore.light_yellow} : '
 				barcode=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"{h}Barcode|Code|Name[b=skips search]: ",helpText="what was consumed?",data="string")
-				if barcode not in [None,]:
+				if barcode not in [None,'d']:
 					while True:
 						try:
 							entry=session.query(Entry).filter(or_(Entry.Barcode==barcode,Entry.Barcode.icontains(barcode),Entry.Name.icontains(barcode),Entry.Code==barcode,Entry.Code.icontains(barcode)))
@@ -162,6 +162,9 @@ class HealthLogUi:
 				return
 			if 'LongActingInsulinName' in useColumns or 'ShortActingInsulinName' in useColumns:
 				def searchNames(code):
+					mp=[]
+					for im in string.printable:
+						mp.extend([f'{im}'*i for i in range(os.get_terminal_size().columns)])
 					if code is None:
 						if 'LongActingInsulinName' in useColumns:
 							return 'Long Acting Insuline Unspecificied - see comments'
@@ -169,6 +172,13 @@ class HealthLogUi:
 							return 'Short Acting Insulin Unspecificied - see comments'
 						else:
 							return 'see comments'
+					elif code in ['d','',*mp]:
+						if 'LongActingInsulinName' in useColumns:
+							return 'Long Acting Insuline Unspecificied - see comments'
+						elif 'ShortActingInsulinName' in useColumns:
+							return 'Short Acting Insulin Unspecificied - see comments'
+						else:
+							return 'see comments'
 					with Session(ENGINE) as session:
 						query=session.query(Entry)
 						filters=[
